aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Channels
diff options
context:
space:
mode:
authorLuke Pulverenti <luke.pulverenti@gmail.com>2014-06-15 19:30:04 -0400
committerLuke Pulverenti <luke.pulverenti@gmail.com>2014-06-15 19:30:04 -0400
commit9e57e16aa9b8f0e639a106c83a2bed2756d8783c (patch)
tree413ab13730350ee682c4fcc62cecec60a81f5fbc /MediaBrowser.Model/Channels
parent918034d803a6aa584a4a1a5a9a7027056d71a590 (diff)
fixes #839 - Support getting latest channel items
Diffstat (limited to 'MediaBrowser.Model/Channels')
-rw-r--r--MediaBrowser.Model/Channels/ChannelFeatures.cs6
-rw-r--r--MediaBrowser.Model/Channels/ChannelQuery.cs11
2 files changed, 13 insertions, 4 deletions
diff --git a/MediaBrowser.Model/Channels/ChannelQuery.cs b/MediaBrowser.Model/Channels/ChannelQuery.cs
index a2f428869c..9d4e26fa65 100644
--- a/MediaBrowser.Model/Channels/ChannelQuery.cs
+++ b/MediaBrowser.Model/Channels/ChannelQuery.cs
@@ -1,4 +1,7 @@
-namespace MediaBrowser.Model.Channels
+using MediaBrowser.Model.Querying;
+using System.Collections.Generic;
+
+namespace MediaBrowser.Model.Channels
{
public class ChannelQuery
{
@@ -54,7 +57,13 @@
ChannelIds = new string[] { };
ContentTypes = new ChannelMediaContentType[] { };
+
+ Filters = new ItemFilter[] { };
+ Fields = new List<ItemFields>();
}
+
+ public ItemFilter[] Filters { get; set; }
+ public List<ItemFields> Fields { get; set; }
}
}
diff --git a/MediaBrowser.Model/Channels/ChannelFeatures.cs b/MediaBrowser.Model/Channels/ChannelFeatures.cs
index 8c41bfde75..0a919f222d 100644
--- a/MediaBrowser.Model/Channels/ChannelFeatures.cs
+++ b/MediaBrowser.Model/Channels/ChannelFeatures.cs
@@ -63,10 +63,10 @@ namespace MediaBrowser.Model.Channels
public bool CanFilter { get; set; }
/// <summary>
/// Gets or sets a value indicating whether this instance can download all media.
/// </summary>
- /// <value><c>true</c> if this instance can download all media; otherwise, <c>false</c>.</value>
- public bool CanDownloadAllMedia { get; set; }
+ /// <value><c>true</c> if [supports content downloading]; otherwise, <c>false</c>.</value>
+ public bool SupportsContentDownloading { get; set; }
public ChannelFeatures()
{
@@ -63,10 +63,10 @@ namespace MediaBrowser.Model.Channels
public bool CanFilter { get; set; }
/// <summary>
- /// Gets or sets a value indicating whether this instance can download all media.
+ /// Gets or sets a value indicating whether [supports content downloading].
/// </summary>